==> fastor_app_ui_widget-1.0.168.tar.gz: lib/resource/template/textfield/validator/ValidatorTemplate.dart <==
import 'package:fastor_app_ui_widget/resource/toolsFastor/values/ToolsValidation.dart';
import 'package:flutter/material.dart';

class ValidatorTemplate {

  //--------------------------------------------------------------------- default

  /**
   * "d" means default
   */
  static FormFieldValidator<String> d( String error_text){



    return ( textValidator) {
      if ( textValidator == null || textValidator.isEmpty) {
        return error_text;
      }
      return null;
    };
  }


  static FormFieldValidator<String> error(String error_text){

    // error_text ??= "Missed";

    return ( textValidator) {
      if ( textValidator == null || textValidator.isEmpty) {
        return error_text;
      }
      return null;
    };
  }

  //------------------------------------------------------------------- special

  static FormFieldValidator<String> mobile( String error_text){

    // String error_text = "Missed Phone";

    return ( text ) {

      if ( ToolsValidation.isPhoneMobileValid( text) == false ) {
        return error_text;
      }

      return null;
    };
  }



  static FormFieldValidator<String> pass( String error_text){

    // String error_text = "Missed Password";

    return ( text ) {

      if ( ToolsValidation.isPasswordValid( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> name(String error_text ){

    // String error_text = "Missed Name";

    return ( text ) {

      if ( ToolsValidation.isName( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> nameFull(String error_text ){

    // String error_text = "Missed Name";

    return ( text ) {

      if ( ToolsValidation.isNameFull( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> moreThan2( String error_text){

    // String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isMoreThan2( text) == false ) {
        return error_text;
      }

      return null;
    };
  }

  static FormFieldValidator<String> email(String error_text) {
    // String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmail( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  //-----------------------------------------------------------------------  by lengh

  static FormFieldValidator<String> min(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //min
      if (   text!.length < len ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> max(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //max
      if (   text!.length > len ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> equal(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //equal
      if (   text!.length != len ) {
        return error_text;
      }

      return null;
    };
  }


}

==> fastor_app_ui_widget-1.0.183.tar.gz: lib/resource/template/textfield/validator/ValidatorTemplate.dart <==
import 'package:fastor_app_ui_widget/resource/toolsFastor/values/ToolsValidation.dart';
import 'package:flutter/material.dart';

class ValidatorTemplate {

  //--------------------------------------------------------------------- default

  /**
   * "d" means default
   */
  static FormFieldValidator<String> d({String? error_text}){

    error_text ??= "Missed";

    return ( textValidator) {
      if ( textValidator == null || textValidator.isEmpty) {
        return error_text;
      }
      return null;
    };
  }


  static FormFieldValidator<String> error( {String? error_text} ){

    error_text ??= "Missed";

    return ( textValidator) {
      if ( textValidator == null || textValidator.isEmpty) {
        return error_text;
      }
      return null;
    };
  }

  //------------------------------------------------------------------- special

  static FormFieldValidator<String> mobile( {String? error_text}){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isPhoneMobileValid( text) == false ) {
        return error_text;
      }

      return null;
    };
  }



  static FormFieldValidator<String> pass( {String? error_text} ){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isPasswordValid( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> name( {String? error_text} ){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isName( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> nameFull( {String? error_text} ){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isNameFull( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> moreThan2( {String? error_text}){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isMoreThan2( text) == false ) {
        return error_text;
      }

      return null;
    };
  }

  static FormFieldValidator<String> email( {String? error_text}){

    error_text ??= "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmail( text) == false ) {
        return error_text;
      }

      return null;
    };
  }


  //-----------------------------------------------------------------------  by lengh

  static FormFieldValidator<String> min(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //min
      if (   text!.length < len ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> max(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //max
      if (   text!.length > len ) {
        return error_text;
      }

      return null;
    };
  }


  static FormFieldValidator<String> equal(int len ){

    String error_text = "Missed";

    return ( text ) {

      if ( ToolsValidation.isEmpty( text) == false ) {
        return error_text;
      }

      //equal
      if (   text!.length != len ) {
        return error_text;
      }

      return null;
    };
  }


}
